![eminus logo](https://gitlab.com/wangenau/eminus/-/raw/master/docs/logo/eminus_logo.png)

# eminus
[![license](https://img.shields.io/badge/license-APACHE2-green)](https://gitlab.com/wangenau/eminus/-/blob/master/LICENSE)
[![language](https://img.shields.io/badge/language-Python3-blue)](https://www.python.org/)
[![DOI](https://zenodo.org/badge/431079841.svg)](https://zenodo.org/badge/latestdoi/431079841)

eminus is a plane wave density functional theory (DFT) code.

It is built upon the [DFT++](https://arxiv.org/abs/cond-mat/9909130) pragmas, that aim to let programming languages and theory coincide.

The goal is to create a simple code that is easy to read and easy to extend while using minimal dependencies.

## Documentation

To learn more about the implementation, take a look inside the [documentation](https://wangenau.gitlab.io/eminus/).

## Installation

The package and all necessary dependencies can be installed using pip

```bash
pip install eminus
```

To also install all optional dependecies to use built-in addons, use

```bash
pip install eminus[addons]
```

## License

This project is licensed under the Apache 2.0 License - see the [LICENSE](https://gitlab.com/wangenau/eminus/-/blob/master/LICENSE) file for details.

